.. _getting-started:

Getting Started
===============

.. _install:

Installation
------------

pyladies can be easily installed using::

   $ pip install pyladies


So You’ve Decided to Start Your Own PyLadies Chapter
----------------------------------------------------

**YAY!** We’re excited to have people like you join our growing community and want to help you get your chapter launched as quickly and painlessly as possible. If our experience is any indication, your first major event will galvanize and inspire the Python community in your area and create momentum for subsequent events, so it’s crucial to start things off on the right foot!

To help you get started, we’ve created an open-source kit for starting your own PyLadies chapter in your city. PyLadies is part social club, part stepping stone toward the Python open-source world.

How to use this kit
-------------------

Copy our model (fork & contribute). Or fork and make it completely different. We don’t mind if you get creative!


Checklist
---------

You may of course adapt this list to meet your chapter’s needs: 

.. raw:: html

	<form action="">
	<ul>
		<li><input type="checkbox" name="coorgs" value="">If you need, find some co-organizers to help with organization and planning</input></li>
		<li><input type="checkbox" name="namespace" value="">Decide the namespace of your chapter (e.g. <code>portland.pyladies.com</code> or <code>pdx.pyladies.com</code>, same with email addresses).</input></li>
		<li><input type="checkbox" name="reqform" value="">Fill out the initial PyLadies chapter request form to get your namespace setup for your chapter domain and email.</input></li>
		<li><input type="checkbox" name="social" value="">Sign up for Twitter, Facebook, Google+ and/or any social network that would be effective in your location.  We suggest to use your @pyladies.com email.</input></li>
		<li><input type="checkbox" name="meetup" value="">Start up a Meetup.com group for your location.</input></li>
		<li><input type="checkbox" name="reimbursement" value="">File for a reimbursement for Meetup fees to the Python Software Foundation.</input></li>
		<li><input type="checkbox" name="heroku" value="">Sign up for a Heroku account (free) if you have not already.</input></li>
		<li><input type="checkbox" name="contactform" value="">Fill out the PyLadies resource form for contact information, all chapter information, etc.</input></li>
		<li><input type="checkbox" name="globalorglist" value="">Request to join the PyLadies Global Organizers list.</input></li>
		<li><input type="checkbox" name="eventplanning" value="">At minimum, try to hold one event a month -- this helps keep interest in PyLadies from flagging, and helps people maintain their progress in becoming better developers. You can hold more events with proper support and planning.</input></li>
		<li><input type="checkbox" name="prompote" value="">Promote the start of the group via various local channels, including meetup.com, local PUGs, related groups, and universities.</input></li>
	</ul>
	</form>

.. **TODO**: create and add link for #3
.. **TODO**: add email address, link to grants, a sample email for #6
.. **TODO**: add link for #8
.. **TODO**: add link for #9
